@@ -4,7 +4,6 @@
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id$
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -36,7 +35,7 @@ private:
     static int sm_overlayWindowX;
     static int sm_overlayWindowY;
 
-    DECLARE_DYNAMIC_CLASS(wxScreenDCImpl)
+    wxDECLARE_DYNAMIC_CLASS(wxScreenDCImpl);
 };
 
 #endif // _WX_DCSCREEN_H_
