@@ -337,7 +337,7 @@ public:
 
     /**
         The @e delete operator is defined for debugging versions of the library only,
-        when the identifier @c __WXDEBUG__ is defined.
+        when the identifier @c \__WXDEBUG__ is defined.
 
         It takes over memory deallocation, allowing wxDebugContext operations.
     */
@@ -345,7 +345,7 @@ public:
 
     /**
         The @e new operator is defined for debugging versions of the library only, when
-        the identifier @c __WXDEBUG__ is defined.
+        the identifier @c \__WXDEBUG__ is defined.
 
         It takes over memory allocation, allowing wxDebugContext operations.
     */
@@ -481,7 +481,7 @@ public:
 
 /**
 
-    This is an helper template class primarily written to avoid memory leaks because
+    This is a helper template class primarily written to avoid memory leaks because
     of missing calls to wxRefCounter::DecRef() and wxObjectRefData::DecRef().
 
     Despite the name this template can actually be used as a smart pointer for any
@@ -583,19 +583,25 @@ public:
         @a ptr is a pointer to the reference counted object to which this class points.
         If @a ptr is not NULL @b T::IncRef() will be called on the object.
     */
-    wxObjectDataPtr<T>(T* ptr = NULL);
+    wxObjectDataPtr(T* ptr = NULL);
 
+    ///@{
     /**
         This copy constructor increases the count of the reference counted object to
         which @a tocopy points and then this class will point to, as well.
+
+        Using @a U different from @c T is only supported since wxWidgets 3.1.5.
     */
-    wxObjectDataPtr<T>(const wxObjectDataPtr<T>& tocopy);
+    template <typename U>
+    wxObjectDataPtr(const wxObjectDataPtr<U>& tocopy);
+    wxObjectDataPtr(const wxObjectDataPtr<T>& tocopy);
+    ///@}
 
 
     /**
         Decreases the reference count of the object to which this class points.
     */
-    ~wxObjectDataPtr<T>();
+    ~wxObjectDataPtr();
 
     /**
         Gets a pointer to the reference counted object to which this class points.
@@ -608,9 +614,24 @@ public:
     */
     void reset(T *ptr);
 
+    /**
+        Release the owned pointer, making caller responsible for decrementing
+        its reference count.
+
+        This method should be used only for interoperating with the existing
+        code working with raw pointers, typically when returning a raw pointer
+        from a function.
+
+        After calling this function, this object becomes invalid, i.e. it
+        doesn't hold any valid pointer value any more.
+
+        @since 3.1.4
+    */
+    T* release();
+
     /**
         Conversion to a boolean expression (in a variant which is not
-        convertable to anything but a boolean expression).
+        convertible to anything but a boolean expression).
 
         If this class contains a valid pointer it will return @true, if it contains
         a @NULL pointer it will return @false.
@@ -631,13 +652,17 @@ public:
     */
     T* operator->() const;
 
-    //@{
+    ///@{
     /**
         Assignment operator.
+
+        Using @a U different from @c T is only supported since wxWidgets 3.1.5.
     */
+    template <typename U>
+    wxObjectDataPtr<T>& operator=(const wxObjectDataPtr<U>& tocopy);
     wxObjectDataPtr<T>& operator=(const wxObjectDataPtr<T>& tocopy);
     wxObjectDataPtr<T>& operator=(T* ptr);
-    //@}
+    ///@}
 };
 
 
@@ -647,7 +672,7 @@ public:
 // ============================================================================
 
 /** @addtogroup group_funcmacro_rtti */
-//@{
+///@{
 
 /**
     Returns a pointer to the wxClassInfo object associated with this class.
@@ -718,7 +743,7 @@ public:
 /**
     Used in a C++ implementation file to complete the declaration of a class
     that has run-time type information.
-    
+
     @header{wx/object.h}
 
     Example:
@@ -726,7 +751,7 @@ public:
     @code
     wxIMPLEMENT_ABSTRACT_CLASS(wxCommand, wxObject);
 
-    wxCommand::wxCommand(void)
+    wxCommand::wxCommand()
     {
         ...
     }
@@ -736,7 +761,7 @@ public:
 
 /**
     Used in a C++ implementation file to complete the declaration of a class
-    that has run-time type information and two base classes. 
+    that has run-time type information and two base classes.
 
     @header{wx/object.h}
 */
@@ -754,7 +779,7 @@ public:
     @code
     wxIMPLEMENT_DYNAMIC_CLASS(wxFrame, wxWindow);
 
-    wxFrame::wxFrame(void)
+    wxFrame::wxFrame()
     {
         ...
     }
@@ -871,10 +896,10 @@ public:
 */
 wxObject *wxCreateDynamicObject(const wxString& className);
 
-//@}
+///@}
 
 /** @addtogroup group_funcmacro_debug */
-//@{
+///@{
 
 /**
     This is defined in debug mode to be call the redefined new operator
@@ -890,5 +915,5 @@ wxObject *wxCreateDynamicObject(const wxString& className);
 */
 #define WXDEBUG_NEW( arg )
 
-//@}
+///@}
 
