@@ -16,9 +16,6 @@
 
 #include "testprec.h"
 
-#ifdef __BORLANDC__
-    #pragma hdrstop
-#endif
 
 #include "wx/app.h"
 #include "wx/wxcrt.h"           // for wxPuts
@@ -29,7 +26,9 @@
 // ----------------------------------------------------------------------------
 
 #define TEST_DYNLIB
+#if wxUSE_MIMETYPE
 #define TEST_MIME
+#endif
 #define TEST_INFO_FUNCTIONS
 #define TEST_STACKWALKER
 #define TEST_STDPATHS
@@ -281,7 +280,7 @@ void InteractiveOutputTestCase::TestPlatformInfo()
     wxPrintf(wxT("Operating system name is: %s\n"), plat.GetOperatingSystemIdName());
     wxPrintf(wxT("Port ID name is: %s\n"), plat.GetPortIdName());
     wxPrintf(wxT("Port ID short name is: %s\n"), plat.GetPortIdShortName());
-    wxPrintf(wxT("Architecture is: %s\n"), plat.GetArchName());
+    wxPrintf(wxT("Architecture bitness is: %s\n"), plat.GetBitnessName());
     wxPrintf(wxT("Endianness is: %s\n"), plat.GetEndiannessName());
 
     wxPuts(wxEmptyString);
@@ -422,7 +421,7 @@ void InteractiveOutputTestCase::TestStandardPaths()
 // wxVolume tests
 // ----------------------------------------------------------------------------
 
-#if !defined(__WIN32__) || !wxUSE_FSVOLUME
+#if (!defined(__WIN32__) && !defined(__APPLE__)) || defined(__WXOSX_IPHONE__) || !wxUSE_FSVOLUME
     #undef TEST_VOLUME
 #endif
 
